#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-Ld2sfCMfutFCRk4TbnbNXV
key:                  ghcide-2.3.0.0-Ld2sfCMfutFCRk4TbnbNXV
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  3e67912226f5ee7ce845d5480a003960
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-Ld2sfCMfutFCRk4TbnbNXV
depends:
    Diff-1.0-2yeHn0RwQ8bEUz2Oy0D0Hq Glob-0.10.2-9nBtPmI8DRmJmYXeJ1G5ef
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf array-0.5.6.0
    async-2.2.6-JCsfEU6uxaM3jchWvvttZs base-4.18.2.1
    base16-bytestring-1.0.2.0-BOZQoJvp04k6zWThJ612WV binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Ewy0DH0xZp6BX0SdeD8DKD
    co-log-core-0.3.2.7-3110G998FNJ3XFFtxkr32S containers-0.6.7
    cryptohash-sha1-0.11.101.0-LkTbORfwvCT5EdDxRYFRu3
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dependent-map-0.4.0.1-9wcQ10VbeyeGoxt4fP4Usl
    dependent-sum-0.7.2.0-3k9BqYTQ9ff17OZK5jWcjX directory-1.3.8.5
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    enummapset-0.7.3.0-BuR2BP25M2f5DqxjbUBM1l exceptions-0.10.7
    extra-1.7.16-8D2X0x8oD0MLkMWmsVnRML filepath-1.4.300.1
    fingertree-0.1.6.3-HAignkIKnfAEv1B30hn7Z2
    focus-1.0.3.2-LPr0zVQmv9Dmkr9CCKBFl ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-H3GKiZxvFA3Jph9zblZU3q
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-I6LznaMN3S07LoCHzvZ03J
    hashable-1.4.7.0-KEzkDU36XICA02zRvxfUEu
    hie-bios-0.12.0-DYOCWo9yHcZ6bKwFSGT8Hr
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-2um3y3EllRjIIKcm9rcoXC
    hls-graph-2.3.0.0-GvTyhJ7gP619osXFZHtN94
    hls-plugin-api-2.3.0.0-9QE7tvrsIC8JO1fH0MMC7Z
    implicit-hie-0.1.4.0-LKQsP5cDwifCDnKoX24fqy
    implicit-hie-cradle-0.5.0.1-Edzn07HLP44IMYMqDsgArH
    lens-5.3.5-2HH8cODx6GtLPPzWDgzNV9
    list-t-1.0.5.7-3jsCfxnKrm9G7FmYdHW6Z4
    lsp-2.2.0.0-1oFCwYFHfFVERkSoDoNvZN
    lsp-types-2.0.2.0-9fW6Rg9QcvUAaTNMaw4g4X mtl-2.3.1
    opentelemetry-0.8.0-LIYiDJupkKiKNXYj4H23qU
    optparse-applicative-0.18.1.0-1bx6NtkYgnV6peHQkP2ZMq
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.2-APthOzNRqmxChDP01Z5Cem
    prettyprinter-ansi-terminal-1.1.4-GwKMc7d2mkH3sDcpoee7Qa
    random-1.2.1.3-HWePNsfMjqy9mivdeOZEPQ
    regex-tdfa-1.3.2.5-90EsLO9aOVj7MSJwUpVHax
    row-types-1.0.1.2-924qizY0EdM99Sucs2tqr1
    safe-exceptions-0.1.7.4-HDQxvGFBJ784b13NqmCpwZ
    sorted-list-0.2.3.1-8Kc0NIbsXTE5U9Xo0mVw51
    sqlite-simple-0.4.19.0-L6ySquZRNoEaLkPBFhF4x stm-2.5.1.0
    stm-containers-1.2.1.1-9iWf57pvJJcDgxvK5JabEc
    syb-0.7.3-KT9hwgimXgJGhH797KmsNL text-2.0.2
    text-rope-0.3-3PwYYVfn9ZnCOd03QiaUYD time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

